from typing import Optional

import typer

from openapi_python_generator.common import HTTPLibrary
from openapi_python_generator.generate_data import generate_data

app = typer.Typer()


@app.command()
def main(file_name :str, output : str, library : Optional[HTTPLibrary]  = HTTPLibrary.httpx) -> None:
    """
    Generate Python code from an OpenAPI 3.0 specification.
    """
    generate_data(file_name, output, library)



if __name__ == "__main__": #pragma: no cover
    app()




from typing import List, Optional

from openapi_schema_pydantic import Schema, PathItem, Operation
from pydantic import BaseModel


class OpReturnType(BaseModel):
    type: str
    status_code: int
    complex_type: bool = False


class ServiceOperation(BaseModel):
    params: List[str]
    operation_id: str
    query_params: List[str]
    return_type: OpReturnType
    operation: Operation
    pathItem: PathItem
    content: str
    async_client: Optional[bool] = False
    tag: Optional[str] = None
    path_name: str
    body_param: Optional[str] = None

class Property(BaseModel):
    name: str
    type: str
    required: bool
    default: Optional[str]


class Model(BaseModel):
    file_name: str
    content: str
    openapi_object: Schema
    references: List[str] = []
    properties: List[Property] = []


class Service(BaseModel):
    file_name: str
    operations: List[ServiceOperation]
    content: str
    async_client: Optional[bool] = False


class APIConfig(BaseModel):
    file_name: str
    content: str


class ConversionResult(BaseModel):
    models: List[Model]
    services: List[Service]
    api_config: APIConfig
